ErrorCodes class
Stable, machine-readable error codes returned to API consumers and used by the CLI to choose exit codes. Always snake_case.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accessDenied → const String
- capabilityUnsupported → const String
- conflictDetected → const String
- driveAlreadyExists → const String
- driveNotFound → const String
- endpointAlreadyExists → const String
- endpointNotFound → const String
- internalError → const String
- invalidJson → const String
- lockHeld → const String
- mountAlreadyExists → const String
- mountNotFound → const String
- notFound → const String
- providerError → const String
- readOnlyViolation → const String
- refMoved → const String
- syncFailed → const String
- unsupportedProvider → const String
- validationError → const String