RefKind enum

The flavor of reference a SyncRef holds.

Inheritance
Available extensions

Values

gitCommitSha → const RefKind

A 40- or 64-char git commit SHA.

directoryManifestHash → const RefKind

A hash over a directory's file manifest.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wireValue → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromWire(String value) → RefKind

Constants

values → const List<RefKind>
A constant List of the values in this enum, in order of their declaration.