omnydrive_cli library

Entry point for the omnydrive command-line tool, exposed as a library so it can be driven from tests as well as bin/omnydrive.dart.

Functions

runOmnydrive(List<String> args) Future<int>
Parses and runs the omnydrive command line, returning a process exit code.

Exceptions / Errors

CliException
A user-facing CLI error that maps to a clean message and exit code 1, without a stack trace.