AccessMode enum
Whether a mounted drive may modify (and synchronize back to) its origin.
Values
- readOnly → const AccessMode
-
Local modifications are never synchronized to the origin; no push/commit.
- readWrite → const AccessMode
-
Local modifications are tracked and may be synchronized back, subject to conflict detection.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isReadOnly → bool
-
no setter
- isReadWrite → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromWire(
String value) → AccessMode
Constants
-
values
→ const List<
AccessMode> - A constant List of the values in this enum, in order of their declaration.