ProgressReporter class
Sink for progress updates. Callers that don't care about progress simply pass null where a ProgressReporter is accepted.
Constructors
- ProgressReporter(void _onEvent(ProgressEvent event))
- ProgressReporter.toSink(void onEvent(ProgressEvent))
-
Builds a reporter that forwards events to a broadcast stream.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
phase(
ProgressPhase phase, String message) → void -
report(
ProgressEvent event) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited